<?php

namespace Inflightor\Util;

use Doctrine\ORM\EntityManager;

class ActiveDirectory
{
    /**
     * @var EntityManager
     */
    private $entityManager;
    /**
     * @var Environment
     */
    private $environment;


    public function __construct(EntityManager $entityManager, $environment) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
    }

    /**
     * @param $username
     * @param $password
     * @param $nrOrg
     */
    public function login($username, $password, $nrOrg = null) {
        $ldap = $this->create_ldap_connection($username, $password, $nrOrg);
        @ldap_close($ldap);
    }

    /**
     * @param $username
     * @param $password
     * @param $nrOrg
     * @throws \Exception
     * @return resource
     */
    private function create_ldap_connection($username, $password, $nrOrg = null) {
        $adServer = $this->getADServer($nrOrg);
        $domain   = $this->getADDomain($nrOrg);
        $ldap = ldap_connect($adServer);
        if (!$ldap) {
            throw new \Exception("Could not connect to the Active Directory server. Check your settings.", 1);
        }

        $ldapRdn = $domain . "\\" . $username;
        ldap_set_option($ldap, LDAP_OPT_PROTOCOL_VERSION, 3);
        ldap_set_option($ldap, LDAP_OPT_REFERRALS, 0);

        $bind = @ldap_bind($ldap, $ldapRdn, $password);
        if (!$bind) {
            throw new \Exception("Active Directory credentials invalid.", 1);
        }

        return $ldap;
    }

    private function getParamSenha($nrOrg) {

        $nrOrg = $nrOrg ? $nrOrg : $this->environment->getNrOrgTrab();

        $stmt = $this->entityManager->getConnection()->prepare("SELECT * FROM PARAMSENHA WHERE NRORG = :NRORG");
        $stmt->execute(array("NRORG" => $nrOrg));
        $result = $stmt->fetch(\PDO::FETCH_ASSOC);
        return $result;

    }

    private function getADDomain($nrOrg = null) {
        $paramSenha = $this->getParamSenha($nrOrg);
        return $paramSenha ? $paramSenha['NMDOMINIOAD'] : false;
    }

    private function getADServer($nrOrg = null) {
        $paramSenha = $this->getParamSenha($nrOrg);
        return $paramSenha ? $paramSenha['DSURLSERVERAD'] : false;
    }

    private function getADAdmUser($nrOrg = null) {
        $paramSenha = $this->getParamSenha($nrOrg);
        return $paramSenha ? $paramSenha['NMUSUARIOADMAD'] : false;
    }

    private function getADAdmPassword($nrOrg = null) {
        $paramSenha = $this->getParamSenha($nrOrg);
        return $paramSenha ? $paramSenha['DSSENHAUSUARIOADMAD'] : false;
    }
}